==> python-polars-1.34.0-2-x86_64.pkg.tar.zst: usr/lib/python3.13/site-packages/polars/functions/__init__.py <==
from polars.functions.aggregation import (
    all,
    all_horizontal,
    any,
    any_horizontal,
    cum_sum,
    cum_sum_horizontal,
    max,
    max_horizontal,
    mean_horizontal,
    min,
    min_horizontal,
    sum,
    sum_horizontal,
)
from polars.functions.as_datatype import (
    concat_arr,
    concat_list,
    concat_str,
    duration,
    format,
    struct,
)
from polars.functions.as_datatype import date_ as date
from polars.functions.as_datatype import datetime_ as datetime
from polars.functions.as_datatype import time_ as time
from polars.functions.business import business_day_count
from polars.functions.col import col
from polars.functions.datatype import dtype_of, self_dtype, struct_with_fields
from polars.functions.eager import align_frames, concat
from polars.functions.escape_regex import escape_regex
from polars.functions.lazy import (
    _row_encode,
    approx_n_unique,
    arctan2,
    arctan2d,
    arg_sort_by,
    arg_where,
    coalesce,
    collect_all,
    collect_all_async,
    corr,
    count,
    cov,
    cum_count,
    cum_fold,
    cum_reduce,
    element,
    exclude,
    explain_all,
    field,
    first,
    fold,
    from_epoch,
    groups,
    head,
    implode,
    last,
    map_batches,
    map_groups,
    mean,
    median,
    n_unique,
    nth,
    quantile,
    reduce,
    rolling_corr,
    rolling_cov,
    row_index,
    select,
    sql_expr,
    std,
    tail,
    var,
)
from polars.functions.len import len
from polars.functions.lit import lit
from polars.functions.random import set_random_seed
from polars.functions.range import (
    arange,
    date_range,
    date_ranges,
    datetime_range,
    datetime_ranges,
    int_range,
    int_ranges,
    linear_space,
    linear_spaces,
    time_range,
    time_ranges,
)
from polars.functions.repeat import ones, repeat, zeros
from polars.functions.whenthen import when

__all__ = [
    # polars.functions.aggregation
    "all",
    "any",
    "cum_sum",
    "max",
    "min",
    "sum",
    "all_horizontal",
    "any_horizontal",
    "cum_sum_horizontal",
    "max_horizontal",
    "min_horizontal",
    "sum_horizontal",
    # polars.functions.datatype
    "dtype_of",
    "self_dtype",
    "struct_with_fields",
    # polars.functions.eager
    "align_frames",
    "approx_n_unique",
    "arg_where",
    "concat",
    "date_range",
    "date_ranges",
    "datetime_range",
    "datetime_ranges",
    "element",
    "ones",
    "repeat",
    "time_range",
    "time_ranges",
    "zeros",
    # polars.functions.lazy
    "_row_encode",
    "arange",
    "arctan2",
    "arctan2d",
    "arg_sort_by",
    "business_day_count",
    "coalesce",
    "col",
    "collect_all",
    "collect_all_async",
    "concat_arr",
    "concat_list",
    "concat_str",
    "corr",
    "count",
    "cov",
    "cum_count",
    "cum_fold",
    "cum_reduce",
    "date",  # named date_, see import above
    "datetime",  # named datetime_, see import above
    "duration",
    "exclude",
    "explain_all",
    "field",
    "first",
    "fold",
    "format",
    "from_epoch",
    "groups",
    "head",
    "implode",
    "int_range",
    "int_ranges",
    "last",
    "linear_space",
    "linear_spaces",
    "lit",
    "map_batches",
    "map_groups",
    "mean",
    "mean_horizontal",
    "median",
    "n_unique",
    "nth",
    "quantile",
    "reduce",
    "rolling_corr",
    "rolling_cov",
    "row_index",
    "select",
    "set_random_seed",
    "std",
    "struct",
    "tail",
    "time",
    "var",
    # polars.functions.len
    "len",
    # polars.functions.whenthen
    "when",
    "sql_expr",
    # polars.functions.escape_regex
    "escape_regex",
]

==> python-polars-1.35.2-1-x86_64.pkg.tar.zst: usr/lib/python3.13/site-packages/polars/functions/__init__.py <==
from polars.functions.aggregation import (
    all,
    all_horizontal,
    any,
    any_horizontal,
    cum_sum,
    cum_sum_horizontal,
    max,
    max_horizontal,
    mean_horizontal,
    min,
    min_horizontal,
    sum,
    sum_horizontal,
)
from polars.functions.as_datatype import (
    concat_arr,
    concat_list,
    concat_str,
    duration,
    format,
    struct,
)
from polars.functions.as_datatype import date_ as date
from polars.functions.as_datatype import datetime_ as datetime
from polars.functions.as_datatype import time_ as time
from polars.functions.business import business_day_count
from polars.functions.col import col
from polars.functions.datatype import dtype_of, self_dtype, struct_with_fields
from polars.functions.eager import align_frames, concat, union
from polars.functions.escape_regex import escape_regex
from polars.functions.lazy import (
    _row_encode,
    approx_n_unique,
    arctan2,
    arctan2d,
    arg_sort_by,
    arg_where,
    coalesce,
    collect_all,
    collect_all_async,
    corr,
    count,
    cov,
    cum_count,
    cum_fold,
    cum_reduce,
    element,
    exclude,
    explain_all,
    field,
    first,
    fold,
    from_epoch,
    groups,
    head,
    implode,
    last,
    map_batches,
    map_groups,
    mean,
    median,
    n_unique,
    nth,
    quantile,
    reduce,
    rolling_corr,
    rolling_cov,
    row_index,
    select,
    sql_expr,
    std,
    tail,
    var,
)
from polars.functions.len import len
from polars.functions.lit import lit
from polars.functions.random import set_random_seed
from polars.functions.range import (
    arange,
    date_range,
    date_ranges,
    datetime_range,
    datetime_ranges,
    int_range,
    int_ranges,
    linear_space,
    linear_spaces,
    time_range,
    time_ranges,
)
from polars.functions.repeat import ones, repeat, zeros
from polars.functions.whenthen import when

__all__ = [
    # polars.functions.aggregation
    "all",
    "any",
    "cum_sum",
    "max",
    "min",
    "sum",
    "all_horizontal",
    "any_horizontal",
    "cum_sum_horizontal",
    "max_horizontal",
    "min_horizontal",
    "sum_horizontal",
    # polars.functions.datatype
    "dtype_of",
    "self_dtype",
    "struct_with_fields",
    # polars.functions.eager
    "align_frames",
    "approx_n_unique",
    "arg_where",
    "concat",
    "union",
    "date_range",
    "date_ranges",
    "datetime_range",
    "datetime_ranges",
    "element",
    "ones",
    "repeat",
    "time_range",
    "time_ranges",
    "zeros",
    # polars.functions.lazy
    "_row_encode",
    "arange",
    "arctan2",
    "arctan2d",
    "arg_sort_by",
    "business_day_count",
    "coalesce",
    "col",
    "collect_all",
    "collect_all_async",
    "concat_arr",
    "concat_list",
    "concat_str",
    "corr",
    "count",
    "cov",
    "cum_count",
    "cum_fold",
    "cum_reduce",
    "date",  # named date_, see import above
    "datetime",  # named datetime_, see import above
    "duration",
    "exclude",
    "explain_all",
    "field",
    "first",
    "fold",
    "format",
    "from_epoch",
    "groups",
    "head",
    "implode",
    "int_range",
    "int_ranges",
    "last",
    "linear_space",
    "linear_spaces",
    "lit",
    "map_batches",
    "map_groups",
    "mean",
    "mean_horizontal",
    "median",
    "n_unique",
    "nth",
    "quantile",
    "reduce",
    "rolling_corr",
    "rolling_cov",
    "row_index",
    "select",
    "set_random_seed",
    "std",
    "struct",
    "tail",
    "time",
    "var",
    # polars.functions.len
    "len",
    # polars.functions.whenthen
    "when",
    "sql_expr",
    # polars.functions.escape_regex
    "escape_regex",
]
